# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 2

# On a released (stable or beta) version set it to 1
%global is_release 1
# On a stable version set it to 1
%global is_stable 1

# On a pre-release packages set this to the selected name
%global prerelease_name beta-2

# On a snapshot packages set this to the selected date and commit.
%global prerelease_date 20161209
%global prerelease_timestamp 1481215650

# pkg_release is what we'll fill in for the rpm Release: field
%if %{is_release}
    %if %{is_stable}
        # stable release
        %global pkg_release %{baserelease}%{?dist}
    %else
        # alpha or beta release
        %global escaped_prerelease_name %(echo %{prerelease_name} |tr -cd [:alnum:])
        %global pkg_release 0.%{baserelease}.%{escaped_prerelease_name}%{?dist}
    %endif
%else
    # nightly build
    %global pkg_release 0.%{baserelease}.%{prerelease_date}snap%{?dist}
%endif

Name:           scilab
Version:        6.0.1
Release:        %{pkg_release}
Summary:        Scientific software package for numerical computations
ExcludeArch:    s390x armv7hl i686

Group:          Applications/Engineering
License:        CeCILL
URL:            http://www.scilab.org/
%if %{is_release}
    %if %{is_stable}
        # stable release
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
    %else
        # alpha or beta release
Source0:        http://www.scilab.org/download/%{version}-%{prerelease_name}/scilab-%{version}-%{prerelease_name}-src.tar.gz
    %endif
%else
    # nightly build
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%endif

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Update to the latest JOGL version
# see https://codereview.scilab.org/#/c/17530/
Patch2:         %{name}-0002-jogl-2.3.2.patch
# Add support for ppc64le
Patch3:         %{name}-0003-fix-ppc64le-build.patch
# Fix the OCaML build
# Patch4:         %{name}-0004-Fix-build-with-ocaml-4.0.4.patch
# Fix Lucene API compat
Patch5:         %{name}-0005-fix-build-with-modern-lucene.patch
# Fix GFortran errors
Patch7:         %{name}-0007-fix-gfortran-errors.patch

# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"

# Mandatory
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-gfortran

# Core
BuildRequires:  libxml2-devel
BuildRequires:  pcre-devel
BuildRequires:  ncurses-devel
BuildRequires:  libcurl-devel
BuildRequires:  eigen3-devel

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
# TBD Packaging guidelines https://fedorahosted.org/fpc/ticket/352
BuildRequires:  lapack-devel
BuildRequires:  arpack-devel

# GUI/Console
BuildRequires:  jpackage-utils
BuildRequires:  java-devel
BuildRequires:  ant

BuildRequires:  flexdock
BuildRequires:  jogl2
BuildRequires:  mesa-libGL-devel

Requires:       flexdock
Requires:       jogl2

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  javahelp2
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  jgraphx
BuildRequires:  lucene
BuildRequires:  lucene-analysis
BuildRequires:  lucene-queryparser
BuildRequires:  fop
BuildRequires:  jeuclid
BuildRequires:  batik
BuildRequires:  xmlgraphics-commons
BuildRequires:  ecj

Requires:       apache-commons-logging
Requires:       javahelp2
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       jgraphx
Requires:       fop
Requires:       jeuclid
Requires:       batik
Requires:       xmlgraphics-commons
Requires:       ecj
Requires:       bwidget

# TCL/TK features
BuildRequires:  tcl-devel
BuildRequires:  tk-devel

Requires:       tcl
Requires:       tk

# Modelica
#BuildRequires:  ocaml
#BuildRequires:  ocaml-num-devel

# Documentation
BuildRequires:  saxon
BuildRequires:  docbook-style-xsl
BuildRequires:  liberation-sans-fonts

# QA tests and validation
BuildRequires:  checkstyle
BuildRequires:  junit

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  gettext-devel
BuildRequires:  fftw-devel
BuildRequires:  matio-devel
BuildRequires:  suitesparse-devel
BuildRequires:  hdf5-devel

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package devel
Group:          Applications/Engineering
License:        CeCILL

Summary:        Scientific software package for numerical computations (include files)

Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide include files for Scilab.

%package doc
Group:          Documentation
License:        CeCILL

Summary:        Scientific software package (documentation files)

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide documentation files for Scilab.

%package tests
Group:          Applications/Engineering
License:        CeCILL

Summary:        Provides test files for Scilab

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       testng

%description tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide test files for Scilab.

%prep
%if %{is_release}
    %if %{is_stable}
%setup -q
    %else
%setup -q -n %{name}-%{version}-%{prerelease_name}
    %endif
%else
%setup -q -n %{name}-master-%{prerelease_timestamp}
%endif

%patch1 -p1 -b .pkgcon
%patch2 -p1 -b .jogl
%patch3 -p1 -b .ppc64le
#%patch4 -p1 -b .ocaml
%patch5 -p1 -b .lucene
%patch7 -p1 -b .gfortran

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml

# Fix file-not-utf8
iconv -f ISO_8859-1 -t UTF-8 COPYING >COPYING.utf8
mv COPYING.utf8 COPYING

# Rename if the builder's home exists
[ -d ~/.Scilab.before.build -a -d ~/.Scilab ] && rm -fr ~/.Scilab || true
[ -d ~/.Scilab ] && mv ~/.Scilab ~/.Scilab.before.build || true


%build
# enforce a specific GL implementation
export LIBGL_ALWAYS_SOFTWARE=1

# disable-static-system-lib: do not static link with compiler libs
# without-emf: disabled because freehep-*.jar are not packaged in fedora and
#              it is a windows specific format
%configure \
  --disable-static-system-lib \
  --without-emf \
  --without-modelica

#make -C modules/scicos modelicac modelicat XML2Modelica
make %{?_smp_mflags}
make %{?_smp_mflags} doc SCIVERBOSE=1

%install
make %{?_smp_mflags} install DESTDIR=%{buildroot}
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%find_lang %{name}

# Remove specific applications, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop \
  %{buildroot}%{_datadir}/applications/scinotes.desktop \
  %{buildroot}%{_datadir}/applications/xcos.desktop
# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-doc.lang

%check
# disabled as linear_algebra spec failed
make check-TESTS || true

%files -f %{name}.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_bindir}/*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
# part of scilab-devel
%exclude %{_datadir}/%{name}/contrib
%exclude %{_datadir}/%{name}/tools
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
%exclude %{_datadir}/%{name}/modules/*/javadoc
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files devel
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools

%files doc -f %{name}-doc.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/doc/%{name}-*
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/*/javadoc

%files tests
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/%{name}/modules/*/tests

%changelog
* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 28 2018 Clément David <c.david86@gmail.com> - 6.0.1-1
- Update to 6.0.1

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Jan 06 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 6.0.0-5
- Remove obsolete scriptlets

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Mar 27 2017 Clément David <c.david86@gmail.com> - 6.0.0-2
- Build with ocaml 4.0.4

* Tue Feb 21 2017 Clément David <c.david86@gmail.com> - 6.0.0-1
- Update to the latest release

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-0.11.20161209snap
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Dec 09 2016 Clément David <c.david86@gmail.com> - 6.0.0-0.9.20161209snap
- fix implicit-function-declaration and implicit-int errors

* Tue Dec 06 2016 Orion Poplawski <orion@cora.nwra.com> - 6.0.0-0.9.beta2
- Rebuild for hdf5 1.8.18

* Sat Nov 05 2016 Richard W.M. Jones <rjones@redhat.com> - 6.0.0-0.8.beta2
- Rebuild for OCaml 4.04.0.

* Wed Jun 29 2016 Orion Poplawski <orion@cora.nwra.com> - 6.0.0-0.7.beta2
- Rebuild for hdf5 1.8.17

* Fri Jun 24 2016 Clément David <c.david86@gmail.com> - 6.0.0-0.6.beta2
- rebuilt

* Thu Jun 23 2016 Clément David <c.david86@gmail.com> - 6.0.0-0.5.beta2
- Update the version

* Thu Mar 10 2016 Peter Robinson <pbrobinson@fedoraproject.org> 6.0.0-0.4.beta1
- Bump Release to 4, so it's not lower than Alpha. 

* Wed Feb 17 2016 Clément David <c.david86@gmail.com> - 6.0.0-0.1.beta1
- Update the version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-0.3.alpha2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 21 2016 Orion Poplawski <orion@cora.nwra.com> - 6.0.0-0.2.alpha2
- Rebuild for hdf5 1.8.16

* Wed Dec 02 2015 Clément David <c.david86@gmail.com> - 6.0.0-0.1.alpha2
- Update version

* Tue Dec 01 2015 Clément David <c.david86@gmail.com> - 6.0.0-0.3.alpha1
- Use appstream-util instead of the deprecated appdata-validate

* Tue Sep 08 2015 Clément David <c.david86@gmail.com> - 6.0.0-0.2.alpha1
- Re-enable the build for ARM

* Tue Sep 08 2015 Clément David <c.david86@gmail.com> - 6.0.0-0.1.alpha1
- Upgrade version to Scilab 6.0.0

* Fri Aug 14 2015 Clément David <c.david86@gmail.com>
- fix build after batik and fop upgrade

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.5.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 11 2015 Nils Philippsen <nils@redhat.com> - 5.5.2-4
- rebuild for suitesparse-4.4.4

* Wed May 20 2015 Clément David <c.david86@gmail.com> - 5.5.2-3
- Disable any specific flags

* Sun May 17 2015 Orion Poplawski <orion@cora.nwra.com> - 5.5.2-2
- Rebuild for hdf5 1.8.15

* Tue Apr 14 2015 Clément David <c.david86@gmail.com> - 5.5.2-1
- Update version

* Tue Mar 24 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 5.5.1-6
- Remove unneeded BR on cobertura

* Tue Feb 03 2015 Clément David <c.david86@gmail.com> - 5.5.1-5
- Remove xcos.desktop scinotes.desktop
- Update to the latest xmlgraphics-common

* Wed Jan 07 2015 Orion Poplawski <orion@cora.nwra.com> - 5.5.1-4
- Rebuild for hdf5 1.8.14

* Fri Dec 12 2014 Clément David <c.david86@gmail.com> - 5.5.1-3
- Re-enable the arm build to check

* Wed Nov 19 2014 Clément David <c.david86@gmail.com> - 5.5.1-2
- Fix Release value

* Fri Oct 03 2014 Clément David <c.david86@gmail.com> - 5.5.1-1.1
- Update version

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.5.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Aug 16 2014 Rex Dieter <rdieter@fedoraproject.org> 5.5.0-7
- update mime scriptlets

* Tue Jun 10 2014 Orion Poplawski <orion@cora.nwra.com> - 5.5.0-6.3
- Rebuild for hdf 1.8.13

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.5.0-5.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 27 2014 Orion Poplawski <orion@cora.nwra.com> - 5.5.0-4.1
- Rebuild for Tcl/Tk 8.6

* Fri May 23 2014 Clément David <c.david86@gmail.com> - 5.5.0-3
- Fix #1026735: bwidget missing dependency
- Fix #1093990: ecj missing dependency

* Wed May 21 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 5.5.0-2.1
- Rebuilt for https://fedoraproject.org/wiki/Changes/f21tcl86

* Fri Apr 11 2014 Clément David <c.david86@gmail.com> - 5.5.0-1
- Update to 5.5.0

* Fri Mar 29 2013 Clément David <c.david86@gmail.com> - 5.4.1-1
- Update to 5.4.1
- disable matio 1.5

* Tue Oct 30 2012 Clément David <c.david86@gmail.com> - 5.4.0-1
- Update to 5.4.0

* Sun Oct 30 2011 <c.david86@gmail.com> 5.3.3-1
- First package

